# colorme-v2

Print hex-colored text in your terminal from Python.

## Features

- Color text using hex codes
- Support for bold and underline styles
- Easy to use API
- Super light-weight

## Installation

```bash
pip install colorme-v2
```

## Usage
```python
from colorme import color_text, bold, underline

print(color_text("Hello, world!", "#FF5733"))
print(bold("Bold Text"))
print(underline("Underlined Text"))
```

# License

this project is licensed under:
GPL-2.0 License